@@ -20,10 +20,27 @@ Authors: Andreas Geiges
 
 from .version import version as __version__
 
+
+# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+try:
+    # Version 0.4.5 patch of personal config
+    from .settings import personal
+    if not hasattr(personal, 'AUTOLOAD_SOURCES'):
+        
+        from .patches import patch_045_update_personal_config
+        
+        personal = patch_045_update_personal_config(personal)
+except:
+    pass
+# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    
+
+
+
 import os
 from . import config
 from . import core
-from .data_structures import Datatable, TableSet, read_csv
+from .data_structures import Datatable, TableSet, read_csv, read_excel
 
 try:
     from . import database
