@@ -279,7 +279,7 @@ class Database():
     
     def getTable(self, ID):
         """
-        Method to return the datatable for the given tableID.
+        Method to load the datatable for the given tableID.
         
         Input
         -----
@@ -297,18 +297,40 @@ class Database():
             
             filePath = self._getTableFilePath(ID)
             return read_csv(filePath)
-        else:
-            #try to load locally from data
+        
+        elif os.path.exists('data'):
+            fileName = self._getTableFileName(ID)
+            filePath = os.path.join('data', fileName)
+            
+            if os.path.exists(filePath):
+                return read_csv(filePath)
             
-            if os.path.exists('data'):
-                fileName = self._getTableFileName(ID)
-                filePath = os.path.join('data', fileName)
                 
-                if os.path.exists(filePath):
+        
+        if config.AUTOLOAD_SOURCES:
+            # trying to import sources from remote on demand
+            source = self._getSourceFromID(ID)
+            
+            try: 
+                if config.DEBUG:
+                    print('Trying to import source {}'.format(source))
+                self.importSourceFromRemote(source)
+                    
+                print("""###########################################################
+                         Successfully imported source: {}
+                         ###########################################################""".format(source))
+                
+                if self._tableExists(ID):
+                # load table from database
+                
+                    filePath = self._getTableFilePath(ID)
                     return read_csv(filePath)
-                else:
-                    raise(BaseException('Table {} not found'.format(ID)))
-
+            except:
+                if config.DEBUG:
+                    print('Failed to import source {}'.format(source))
+        
+        raise(BaseException('Table {} not found'.format(ID)))
+        
     def getTables(self, iterIDs):
         """
         Method to return multiple datatables at once as a dictionary like 
@@ -1026,8 +1048,10 @@ class GitRepository_Manager:
             return 
 
         origin = repo.create_remote("origin", config.DATASHELF_REMOTE + repoName + ".git")
+        origin.push(refspec="master:origin")
         origin.fetch()
 
+        # TODO maybe switch next two commands
         repo.heads.master.set_tracking_branch(origin.refs.master)
         origin.push(repo.heads.master)
     
